==> muitv-0.4.0.tgz: package/src/components/demo/ConsumptionDemo.js <==
import React, { Component } from "react";

import Consumption from "components/layouts/Consumption";

import LinearProgress from "@material-ui/core/LinearProgress";
import { withStyles } from "@material-ui/core/styles";
import IconButton from "@material-ui/core/IconButton";
import DeleteIcon from "@material-ui/icons/Delete";

const styles = theme => ({
  button1: {
    margin: theme.spacing.unit,
    height: '2em',
    width: '2em'
  },
  icon1: {
    width: '1em',
    height: '1em'
  },
  button2: {
    margin: theme.spacing.unit * 1.3,
    height: '2.6em',
    width: '2.6em'
  },
  icon2: {
    width: '1.3em',
    height: '1.3em'
  },
  button3: {
    margin: theme.spacing.unit * 2,
    height: '4em',
    width: '4em'
  },
  icon3: {
    width: '2em',
    height: '2em'
  },
  video: {
    position: "fixed",
    top: "50%",
    left: "50%",
    transform: "translate(-50%, -50%)",
    width: "100%",
    height: "auto",
    zIndex: 0
  }
});

class ConsumptionDemo extends Component {
  render() {
    const ih = window.innerHeight;
    const { classes } = this.props;
    const title = "Consumption";
    const subtitle = "Demo";
    const leftValue = "35:00";
    const rightValue = "1:40:00";
    const progress = <LinearProgress variant="determinate" value={35} />;

    const buttonClass = ih > 1000 ? classes.button3 : ih > 700 ? classes.button2 : classes.button1;
    const iconClass = ih > 1000 ? classes.icon3 : ih > 700 ? classes.icon2 : classes.icon1;

    const buttons = [
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton
        variant="fab"
        color="secondary"
        className={buttonClass}
        aria-label="Delete"
      >
      <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>
    ];

    const footerButtons = [
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>
    ];

    const video = (
      <img
        alt=''
        src="http://via.placeholder.com/1280x720"
        className={classes.video}
      />
    );

    const cprops = {
      title,
      subtitle,
      progress,
      buttons,
      footerButtons,
      leftValue,
      rightValue,
      video
    };

    return <Consumption {...cprops} />;
  }
}

export default withStyles(styles)(ConsumptionDemo);

==> muitv-0.6.1.tgz: package/src/components/demo/ConsumptionDemo.js <==
import React, { Component } from "react";

import Consumption from "components/layouts/Consumption";

import LinearProgress from "@material-ui/core/LinearProgress";
import { withStyles } from "@material-ui/core/styles";
import IconButton from "@material-ui/core/IconButton";
import DeleteIcon from "@material-ui/icons/Delete";

const styles = theme => ({
  button1: {
    margin: theme.spacing(1),
    height: '2em',
    width: '2em'
  },
  icon1: {
    width: '1em',
    height: '1em'
  },
  button2: {
    margin: theme.spacing(1.3),
    height: '2.6em',
    width: '2.6em'
  },
  icon2: {
    width: '1.3em',
    height: '1.3em'
  },
  button3: {
    margin: theme.spacing(2),
    height: '4em',
    width: '4em'
  },
  icon3: {
    width: '2em',
    height: '2em'
  },
  video: {
    position: "fixed",
    top: "50%",
    left: "50%",
    transform: "translate(-50%, -50%)",
    width: "100%",
    height: "auto",
    zIndex: 0
  }
});

class ConsumptionDemo extends Component {
  render() {
    const ih = window.innerHeight;
    const { classes } = this.props;
    const title = "Consumption";
    const subtitle = "Demo";
    const leftValue = "35:00";
    const rightValue = "1:40:00";
    const progress = <LinearProgress variant="determinate" value={35} />;

    const buttonClass = ih > 1000 ? classes.button3 : ih > 700 ? classes.button2 : classes.button1;
    const iconClass = ih > 1000 ? classes.icon3 : ih > 700 ? classes.icon2 : classes.icon1;

    const buttons = [
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton
        variant="fab"
        color="secondary"
        className={buttonClass}
        aria-label="Delete"
      >
      <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>
    ];

    const footerButtons = [
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>
    ];

    const video = (
      <img
        alt=''
        src="http://via.placeholder.com/1280x720"
        className={classes.video}
      />
    );

    const cprops = {
      title,
      subtitle,
      progress,
      buttons,
      footerButtons,
      leftValue,
      rightValue,
      video
    };

    return <Consumption {...cprops} />;
  }
}

export default withStyles(styles)(ConsumptionDemo);
